@@ -60,9 +60,7 @@ def init_logger(level: int = logging.DEBUG, app: str = "default") -> Logger:
     log4, handlr = get_logger(level, app), get_handler(level)
 
     fmt = logging.Formatter(
-        get_orlog_fmt()
-        | f"%(name)s [%(asctime)s - %(levelname)s]" + get_andlog_fmt()
-        | " %(message)s",
+        get_orlog_fmt() | f"%(name)s [%(asctime)s - %(levelname)s] %(message)s",
         # Imagine if we could render a clock from  3 svgs just in time lol
         "%m-%d %H:%M:%S",
     )
